@@ -21,16 +21,16 @@ ExtUtils::Command - utilities to replace common UNIX commands in Makefiles etc.
 
 =head1 SYNOPSIS
 
-  perl -MExtUtils::Command -e cat files... > destination
-  perl -MExtUtils::Command -e mv source... destination
-  perl -MExtUtils::Command -e cp source... destination
-  perl -MExtUtils::Command -e touch files...
-  perl -MExtUtils::Command -e rm_f file...
-  perl -MExtUtils::Command -e rm_rf directories...
-  perl -MExtUtils::Command -e mkpath directories...
-  perl -MExtUtils::Command -e eqtime source destination
-  perl -MExtUtils::Command -e chmod mode files...
-  perl -MExtUtils::Command -e test_f file
+  perl -MExtUtils::Command       -e cat files... > destination
+  perl -MExtUtils::Command       -e mv source... destination
+  perl -MExtUtils::Command       -e cp source... destination
+  perl -MExtUtils::Command       -e touch files...
+  perl -MExtUtils::Command       -e rm_f files...
+  perl -MExtUtils::Command       -e rm_rf directories...
+  perl -MExtUtils::Command       -e mkpath directories...
+  perl -MExtUtils::Command       -e eqtime source destination
+  perl -MExtUtils::Command       -e test_f file
+  perl -MExtUtils::Command=chmod -e chmod mode files...
 
 =head1 DESCRIPTION
 
@@ -57,6 +57,7 @@ sub expand_wildcards
  @ARGV = map(/[$wild_regex]/o ? glob($_) : $_,@ARGV);
 }
 
+
 =item cat 
 
 Concatenates all files mentioned on command line to STDOUT.
@@ -78,8 +79,7 @@ Sets modified time of dst to that of src
 sub eqtime
 {
  my ($src,$dst) = @ARGV;
- open(F,">$dst");
- close(F);
+ local @ARGV = ($dst);  touch();  # in case $dst doesn't exist
  utime((stat($src))[8,9],$dst);
 }
 
@@ -106,9 +106,9 @@ sub rm_f
  expand_wildcards();
  foreach (@ARGV)
   {
-   next unless -f $_;        
+   next unless -f $_;
    next if unlink($_);
-   chmod(0777,$_);           
+   chmod(0777,$_);
    next if unlink($_);
    carp "Cannot delete $_:$!";
   }
@@ -120,17 +120,14 @@ Makes files exist, with current timestamp
 
 =cut 
 
-sub touch
-{
- my $t    = time;
- expand_wildcards();
- while (@ARGV)
-  {
-   my $file = shift(@ARGV);               
-   open(FILE,">>$file") || die "Cannot write $file:$!";
-   close(FILE);
-   utime($t,$t,$file);
-  }
+sub touch {
+    my $t    = time;
+    expand_wildcards();
+    foreach my $file (@ARGV) {
+        open(FILE,">>$file") || die "Cannot write $file:$!";
+        close(FILE);
+        utime($t,$t,$file);
+    }
 }
 
 =item mv source... destination
@@ -140,16 +137,13 @@ Multiple sources are allowed if destination is an existing directory.
 
 =cut 
 
-sub mv
-{
- my $dst = pop(@ARGV);
- expand_wildcards();
- croak("Too many arguments") if (@ARGV > 1 && ! -d $dst);
- while (@ARGV)
-  {
-   my $src = shift(@ARGV);               
-   move($src,$dst);
-  }
+sub mv {
+    my $dst = pop(@ARGV);
+    expand_wildcards();
+    croak("Too many arguments") if (@ARGV > 1 && ! -d $dst);
+    foreach my $src (@ARGV) {
+        move($src,$dst);
+    }
 }
 
 =item cp source... destination
@@ -157,31 +151,27 @@ sub mv
 Copies source to destination.
 Multiple sources are allowed if destination is an existing directory.
 
-=cut 
+=cut
 
-sub cp
-{
- my $dst = pop(@ARGV);
- expand_wildcards();
- croak("Too many arguments") if (@ARGV > 1 && ! -d $dst);
- while (@ARGV)
-  {
-   my $src = shift(@ARGV);               
-   copy($src,$dst);
-  }
+sub cp {
+    my $dst = pop(@ARGV);
+    expand_wildcards();
+    croak("Too many arguments") if (@ARGV > 1 && ! -d $dst);
+    foreach my $src (@ARGV) {
+        copy($src,$dst);
+    }
 }
 
 =item chmod mode files...
 
-Sets UNIX like permissions 'mode' on all the files.
+Sets UNIX like permissions 'mode' on all the files.  e.g. 0666
 
 =cut 
 
-sub chmod
-{
- my $mode = shift(@ARGV);
- expand_wildcards();
- chmod($mode,@ARGV) || die "Cannot chmod ".join(' ',$mode,@ARGV).":$!";
+sub chmod {
+    my $mode = shift(@ARGV);
+    expand_wildcards();
+    chmod(oct $mode,@ARGV) || die "Cannot chmod ".join(' ',$mode,@ARGV).":$!";
 }
 
 =item mkpath directory...
