@@ -1,5 +1,8 @@
 package ExtUtils::Liblist;
 
+use vars qw($VERSION);
+$VERSION = '1.00';
+
 use File::Spec;
 require ExtUtils::Liblist::Kid;
 @ISA = qw(ExtUtils::Liblist::Kid File::Spec);
@@ -8,8 +11,9 @@ sub lsdir {
   shift;
   my $rex = qr/$_[1]/;
   opendir DIR, $_[0];
-  grep /$rex/, readdir DIR;
+  my @out = grep /$rex/, readdir DIR;
   closedir DIR;
+  return @out;
 }
 
 __END__
