@@ -18,7 +18,6 @@ use Config;
 use Cwd 'cwd';
 require Exporter;
 use File::Basename;
-use File::Spec;
 use vars qw(%make_data);
 
 my $Mac_FS = eval { require Mac::FileSpec::Unixish };
@@ -37,6 +36,8 @@ ExtUtils::MM_MacOS - methods to override UN*X behaviour in ExtUtils::MakeMaker
 
 MM_MacOS currently only produces an approximation to the correct Makefile.
 
+=over 4
+
 =cut
 
 sub new {
@@ -159,7 +160,7 @@ END
 	    pasthru c_o xs_c xs_o top_targets linkext 
 	    dynamic_bs dynamic_lib static_lib manifypods
 	    installbin subdirs dist_basics dist_core
-	    dist_dir dist_test dist_ci install force perldepend makefile
+	    distdir dist_test dist_ci install force perldepend makefile
 	    staticmake test pm_to_blib selfdocument
 	    const_loadlibs const_cccmd
     /)
@@ -170,7 +171,7 @@ END
     	unless grep /rulez/, @ExtUtils::MakeMaker::MM_Sections;
 
     if ($self->{PARENT}) {
-	for (qw/install dist dist_basics dist_core dist_dir dist_test dist_ci/) {
+	for (qw/install dist dist_basics dist_core distdir dist_test dist_ci/) {
 	    $self->{SKIPHASH}{$_} = 1;
 	}
     }
@@ -337,7 +338,7 @@ sub init_main {
 	}
     }
     if ($self->{PERL_SRC}){
-	$self->{PERL_LIB}     ||= File::Spec->catdir("$self->{PERL_SRC}","lib");
+	$self->{PERL_LIB}     ||= $self->catdir("$self->{PERL_SRC}","lib");
 	$self->{PERL_ARCHLIB} = $self->{PERL_LIB};
 	$self->{PERL_INC}     = $self->{PERL_SRC};
     } else {
@@ -425,7 +426,7 @@ sub init_main {
     # will be working versions of perl 5. miniperl has priority over perl
     # for PERL to ensure that $(PERL) is usable while building ./ext/*
     my ($component,@defpath);
-    foreach $component ($self->{PERL_SRC}, File::Spec->path(), $Config::Config{binexp}) {
+    foreach $component ($self->{PERL_SRC}, $self->path(), $Config::Config{binexp}) {
 	push @defpath, $component if defined $component;
     }
     $self->{PERL} = "$self->{PERL_SRC}miniperl";
@@ -490,8 +491,8 @@ XXX Few are initialized.  How many of these are ever used?
 sub init_platform {
     my $self = shift;
 
-    $self->{MACPERL_SRC}  = File::Spec->catdir("$self->{PERL_SRC}","macos:");
-    $self->{MACPERL_LIB}  ||= File::Spec->catdir("$self->{MACPERL_SRC}","lib");
+    $self->{MACPERL_SRC}  = $self->catdir("$self->{PERL_SRC}","macos:");
+    $self->{MACPERL_LIB}  ||= $self->catdir("$self->{MACPERL_SRC}","lib");
     $self->{MACPERL_INC}  = $self->{MACPERL_SRC};
 }
 
@@ -512,10 +513,6 @@ sub platform_constants {
 }
 
 
-=cut
-
-sub 
-
 =item init_dirscan
 
 Initializes DIR, XS, PM, C, O_FILES, H, PL_FILES, MAN*PODS, EXE_FILES.
@@ -935,6 +932,8 @@ sub _include {  # for Unix-style includes, with -I instead of -i
 	}
 }
 
-1;
+=back
 
-__END__
+=cut
+
+1;
